@@ -12,6 +12,7 @@
 #include <Akonadi/Item>
 #include <QItemSelection>
 #include <QWidget>
+class ContactEntityMimeTypeFilterModel;
 
 namespace GrantleeTheme
 {
@@ -96,45 +97,45 @@ public Q_SLOTS:
 protected:
     [[nodiscard]] bool event(QEvent *e) override;
 
-private Q_SLOTS:
-    void slotImportExportActivated(PimCommon::AbstractGenericPluginInterface *interface);
-    void delayedInit();
-
-    void itemSelected(const Akonadi::Item &item);
-    void itemSelectionChanged(const QModelIndex &, const QModelIndex &);
-    void selectFirstItem();
-
-    void setActivateViewMode(QAction *action);
-    void setQRCodeShow(bool on);
-
-    void restoreState();
-    void saveState();
-
-    void slotGrantleeThemeSelected();
-    void slotGrantleeThemesUpdated();
-    void slotCheckNewCalendar(const QModelIndex &parent, int begin, int end);
-
-    void slotDebugAkonadiSearch();
-    void slotServerSideSubscription();
-    void slotCurrentCollectionChanged(const Akonadi::Collection &col);
-    void setFocusToTreeView();
-
 private:
-    const Akonadi::Item::List collectSelectedAllContactsItem(QItemSelectionModel *model);
-    void initGrantleeThemeName();
-    void setupGui();
-    void setupActions(KActionCollection *);
-    bool showQRCodes();
-    void setViewMode(int mode);
-    void saveSplitterStates() const;
-    void restoreSplitterStates();
-    void initializeImportExportPlugin(KActionCollection *collection);
-    void slotGeneralPaletteChanged();
-    Akonadi::EntityTreeModel *entityTreeModel() const;
+    KADDRESSBOOK_NO_EXPORT void slotImportExportActivated(PimCommon::AbstractGenericPluginInterface *interface);
+    KADDRESSBOOK_NO_EXPORT void delayedInit();
 
-    QAbstractItemModel *allContactsModel();
+    KADDRESSBOOK_NO_EXPORT void itemSelected(const Akonadi::Item &item);
+    KADDRESSBOOK_NO_EXPORT void itemSelectionChanged(const QModelIndex &, const QModelIndex &);
+    KADDRESSBOOK_NO_EXPORT void selectFirstItem();
 
-    Akonadi::EntityMimeTypeFilterModel *mCollectionTree = nullptr;
+    KADDRESSBOOK_NO_EXPORT void setActivateViewMode(QAction *action);
+    KADDRESSBOOK_NO_EXPORT void setQRCodeShow(bool on);
+
+    KADDRESSBOOK_NO_EXPORT void restoreState();
+    KADDRESSBOOK_NO_EXPORT void saveState();
+
+    KADDRESSBOOK_NO_EXPORT void slotGrantleeThemeSelected();
+    KADDRESSBOOK_NO_EXPORT void slotGrantleeThemesUpdated();
+    KADDRESSBOOK_NO_EXPORT void slotCheckNewCalendar(const QModelIndex &parent, int begin, int end);
+
+    KADDRESSBOOK_NO_EXPORT void slotDebugAkonadiSearch();
+    KADDRESSBOOK_NO_EXPORT void slotServerSideSubscription();
+    KADDRESSBOOK_NO_EXPORT void slotCurrentCollectionChanged(const Akonadi::Collection &col);
+    KADDRESSBOOK_NO_EXPORT void setFocusToTreeView();
+
+    KADDRESSBOOK_NO_EXPORT const Akonadi::Item::List collectSelectedAllContactsItem(QItemSelectionModel *model);
+    KADDRESSBOOK_NO_EXPORT void initGrantleeThemeName();
+    KADDRESSBOOK_NO_EXPORT void setupGui();
+    KADDRESSBOOK_NO_EXPORT void setupActions(KActionCollection *);
+    KADDRESSBOOK_NO_EXPORT bool showQRCodes();
+    KADDRESSBOOK_NO_EXPORT void setViewMode(int mode);
+    KADDRESSBOOK_NO_EXPORT void saveSplitterStates() const;
+    KADDRESSBOOK_NO_EXPORT void restoreSplitterStates();
+    KADDRESSBOOK_NO_EXPORT void initializeImportExportPlugin(KActionCollection *collection);
+    KADDRESSBOOK_NO_EXPORT void slotGeneralPaletteChanged();
+    KADDRESSBOOK_NO_EXPORT void slotWhatsNew();
+    KADDRESSBOOK_NO_EXPORT Akonadi::EntityTreeModel *entityTreeModel() const;
+
+    KADDRESSBOOK_NO_EXPORT QAbstractItemModel *allContactsModel();
+
+    ContactEntityMimeTypeFilterModel *mCollectionTree = nullptr;
     Akonadi::EntityMimeTypeFilterModel *mItemTree = nullptr;
     Akonadi::EntityMimeTypeFilterModel *mAllContactsModel = nullptr;
     Akonadi::ContactsFilterProxyModel *mContactsFilterModel = nullptr;
